Index: third_party/WebKit/public/web/WebFrameClient.h |
diff --git a/third_party/WebKit/public/web/WebFrameClient.h b/third_party/WebKit/public/web/WebFrameClient.h |
index 0fd5e49fd26d68b8ef62a66d36ae0a2beb9b5840..096156325315c2f040951b70dbb84f063c5bbf00 100644 |
--- a/third_party/WebKit/public/web/WebFrameClient.h |
+++ b/third_party/WebKit/public/web/WebFrameClient.h |
@@ -179,12 +179,14 @@ class BLINK_EXPORT WebFrameClient { |
// to prevent the new child frame from being attached. Otherwise, embedders |
// should create a new WebLocalFrame, insert it into the frame tree, and |
// return the created frame. |
- virtual WebLocalFrame* createChildFrame(WebLocalFrame* parent, |
- WebTreeScopeType, |
- const WebString& name, |
- const WebString& fallbackName, |
- WebSandboxFlags sandboxFlags, |
- const WebFrameOwnerProperties&) { |
+ virtual WebLocalFrame* createChildFrame( |
+ WebLocalFrame* parent, |
+ WebTreeScopeType, |
+ const WebString& name, |
+ const WebString& fallbackName, |
+ WebSandboxFlags sandboxFlags, |
+ const WebParsedFeaturePolicy& containerPolicy, |
+ const WebFrameOwnerProperties&) { |
return nullptr; |
} |
@@ -222,9 +224,12 @@ class BLINK_EXPORT WebFrameClient { |
virtual void didUpdateToUniqueOrigin( |
bool isPotentiallyTrustworthyUniqueOrigin) {} |
- // The sandbox flags have changed for a child frame of this frame. |
- virtual void didChangeSandboxFlags(WebFrame* childFrame, |
- WebSandboxFlags flags) {} |
+ // The sandbox flags or container policy have changed for a child frame of |
+ // this frame. |
+ virtual void didChangeFramePolicy( |
+ WebFrame* childFrame, |
+ WebSandboxFlags flags, |
+ const WebParsedFeaturePolicy& containerPolicy) {} |
// Called when a Feature-Policy HTTP header is encountered while loading the |
// frame's document. |